summaryrefslogtreecommitdiffstats
path: root/kresources/scalix/kcal/resourcescalix.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/scalix/kcal/resourcescalix.cpp')
-rw-r--r--kresources/scalix/kcal/resourcescalix.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kresources/scalix/kcal/resourcescalix.cpp b/kresources/scalix/kcal/resourcescalix.cpp
index 1d74c570..8c84977a 100644
--- a/kresources/scalix/kcal/resourcescalix.cpp
+++ b/kresources/scalix/kcal/resourcescalix.cpp
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -249,7 +249,7 @@ void ResourceScalix::removeIncidences( const TQCString& incidenceType )
// better call event(uid), todo(uid) etc. directly.
// A faster but hackish way would probably be to check the type of the resource,
// like mEventSubResources.find( it.data().resource() ) != mEventSubResources.end() ?
const TQString& uid = it.key();
if ( incidenceType == "Event" && mCalendar.event( uid ) )
mUidMap.remove( it );
@@ -268,7 +268,7 @@ bool ResourceScalix::doSave()
void ResourceScalix::incidenceUpdated( KCal::IncidenceBase* incidencebase )
{
if ( incidencebase->isReadOnly() ) return; // Should not happen (TM)
- incidencebase->setSyncStatus( KCal::Event::SYNCMOD );
+ incidencebase->setSynctqStatus( KCal::Event::SYNCMOD );
incidencebase->setLastModified( TQDateTime::tqcurrentDateTime() );
// we should probably update the revision number here,
// or internally in the Event itself when certain things change.
@@ -482,7 +482,7 @@ bool ResourceScalix::addIncidence( KCal::Incidence* incidence, const TQString& _
}
}
/* Check if there are updates for this uid pending and if so process them. */
- if ( KCal::IncidenceBase *update = mPendingUpdates.find( uid ) ) {
+ if ( KCal::IncidenceBase *update = mPendingUpdates.tqfind( uid ) ) {
mSilent = false; // we do want to tell KMail
mPendingUpdates.remove( uid );
incidenceUpdated( update );
@@ -507,7 +507,7 @@ bool ResourceScalix::addEvent( KCal::Event* event )
if ( mUidMap.tqcontains( event->uid() ) )
return true; //noop
else
- return addIncidence( event, TQString::null, 0 );
+ return addIncidence( event, TQString(), 0 );
}
bool ResourceScalix::addEvent( KCal::Event *event, const TQString &subresource )
@@ -575,7 +575,7 @@ bool ResourceScalix::addTodo( KCal::Todo* todo )
if ( mUidMap.tqcontains( todo->uid() ) )
return true; //noop
else
- return addIncidence( todo, TQString::null, 0 );
+ return addIncidence( todo, TQString(), 0 );
}
bool ResourceScalix::addTodo( KCal::Todo *todo, const TQString &subresource )
@@ -609,7 +609,7 @@ bool ResourceScalix::addJournal( KCal::Journal* journal )
if ( mUidMap.tqcontains( journal->uid() ) )
return true; //noop
else
- return addIncidence( journal, TQString::null, 0 );
+ return addIncidence( journal, TQString(), 0 );
}
bool ResourceScalix::addJournal( KCal::Journal *journal, const TQString &subresource )
@@ -693,7 +693,7 @@ void ResourceScalix::fromKMailDelIncidence( const TQString& type,
mUidsPendingDeletion.remove( uid );
} else if ( mUidsPendingUpdate.tqcontains( uid ) ) {
// It's good to know if was deleted, but we are waiting on a new one to
- // tqreplace it, so let's just sit tight.
+ // replace it, so let's just sit tight.
} else {
// We didn't trigger this, so KMail did, remove the reference to the uid
KCal::Incidence* incidence = mCalendar.incidence( uid );
@@ -804,7 +804,7 @@ TQStringList ResourceScalix::subresources() const
+ mJournalSubResources.keys() );
}
-const QString
+const TQString
ResourceScalix::labelForSubresource( const TQString& subresource ) const
{
if ( mEventSubResources.tqcontains( subresource ) )
@@ -249,7 +249,7 @@ void ResourceScalix::removeIncidences( const TQCString& incidenceType )
// better call event(uid), todo(uid) etc. directly.
// A faster but hackish way would probably be to check the type of the resource,
- // like mEventSubResources.find( it.data().resource() ) != mEventSubResources.end() ?
+ // like mEventSubResources.tqfind( it.data().resource() ) != mEventSubResources.end() ?
const TQString& uid = it.key();
if ( incidenceType == "Event" && mCalendar.event( uid ) )